@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,18 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 import warnings
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.bigquery_datatransfer_v1.services.data_transfer_service import pagers
 from google.cloud.bigquery_datatransfer_v1.types import datatransfer
@@ -43,10 +46,8 @@ from .client import DataTransferServiceClient
 
 
 class DataTransferServiceAsyncClient:
-    """The Google BigQuery Data Transfer Service API enables
-    BigQuery users to configure the transfer of their data from
-    other Google Products into BigQuery. This service contains
-    methods that are end user exposed. It backs up the frontend.
+    """This API allows users to manage their data transfers into
+    BigQuery.
     """
 
     _client: DataTransferServiceClient
@@ -122,6 +123,42 @@ class DataTransferServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return DataTransferServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> DataTransferServiceTransport:
         """Returns the transport used by the client instance.
@@ -193,7 +230,27 @@ class DataTransferServiceAsyncClient:
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.DataSource:
         r"""Retrieves a supported data source and returns its
-        settings, which can be used for UI rendering.
+        settings.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_get_data_source():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.GetDataSourceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_data_source(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.GetDataSourceRequest, dict]):
@@ -216,13 +273,12 @@ class DataTransferServiceAsyncClient:
 
         Returns:
             google.cloud.bigquery_datatransfer_v1.types.DataSource:
-                Represents data source metadata.
-                Metadata is sufficient to render UI and
-                request proper OAuth tokens.
+                Defines the properties and custom
+                parameters for a data source.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -278,7 +334,28 @@ class DataTransferServiceAsyncClient:
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataSourcesAsyncPager:
         r"""Lists supported data sources and returns their
-        settings, which can be used for UI rendering.
+        settings.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_data_sources():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListDataSourcesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_data_sources(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesRequest, dict]):
@@ -309,7 +386,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -373,6 +450,29 @@ class DataTransferServiceAsyncClient:
     ) -> transfer.TransferConfig:
         r"""Creates a new data transfer configuration.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_create_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                transfer_config = bigquery_datatransfer_v1.TransferConfig()
+                transfer_config.destination_dataset_id = "destination_dataset_id_value"
+
+                request = bigquery_datatransfer_v1.CreateTransferConfigRequest(
+                    parent="parent_value",
+                    transfer_config=transfer_config,
+                )
+
+                # Make the request
+                response = client.create_transfer_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.CreateTransferConfigRequest, dict]):
                 The request object. A request to create a data transfer
@@ -420,7 +520,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, transfer_config])
         if request is not None and has_flattened_params:
@@ -471,6 +571,29 @@ class DataTransferServiceAsyncClient:
         r"""Updates a data transfer configuration.
         All fields must be set, even if they are not updated.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_update_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                transfer_config = bigquery_datatransfer_v1.TransferConfig()
+                transfer_config.destination_dataset_id = "destination_dataset_id_value"
+
+                request = bigquery_datatransfer_v1.UpdateTransferConfigRequest(
+                    transfer_config=transfer_config,
+                )
+
+                # Make the request
+                response = client.update_transfer_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.UpdateTransferConfigRequest, dict]):
                 The request object. A request to update a transfer
@@ -510,7 +633,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([transfer_config, update_mask])
         if request is not None and has_flattened_params:
@@ -559,8 +682,25 @@ class DataTransferServiceAsyncClient:
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
-        r"""Deletes a data transfer configuration,
-        including any associated transfer runs and logs.
+        r"""Deletes a data transfer configuration, including any
+        associated transfer runs and logs.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_delete_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.DeleteTransferConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_transfer_config(request=request)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.DeleteTransferConfigRequest, dict]):
@@ -583,7 +723,7 @@ class DataTransferServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -639,6 +779,25 @@ class DataTransferServiceAsyncClient:
     ) -> transfer.TransferConfig:
         r"""Returns information about a data transfer config.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_get_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.GetTransferConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_transfer_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.GetTransferConfigRequest, dict]):
                 The request object. A request to get data transfer
@@ -671,7 +830,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -729,6 +888,27 @@ class DataTransferServiceAsyncClient:
         r"""Returns information about all transfer configs owned
         by a project in the specified location.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_transfer_configs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListTransferConfigsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_transfer_configs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsRequest, dict]):
                 The request object. A request to list data transfers
@@ -757,7 +937,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -826,6 +1006,26 @@ class DataTransferServiceAsyncClient:
         created per UTC time in the time range. DEPRECATED: use
         StartManualTransferRuns instead.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_schedule_transfer_runs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ScheduleTransferRunsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.schedule_transfer_runs(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ScheduleTransferRunsRequest, dict]):
                 The request object. A request to schedule transfer runs
@@ -870,7 +1070,7 @@ class DataTransferServiceAsyncClient:
         )
 
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, start_time, end_time])
         if request is not None and has_flattened_params:
@@ -923,6 +1123,25 @@ class DataTransferServiceAsyncClient:
         time range where the run_time is between start_time (inclusive)
         and end_time (exclusive), or for a specific run_time.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_start_manual_transfer_runs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.StartManualTransferRunsRequest(
+                )
+
+                # Make the request
+                response = client.start_manual_transfer_runs(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.StartManualTransferRunsRequest, dict]):
                 The request object. A request to start manual transfer
@@ -974,6 +1193,26 @@ class DataTransferServiceAsyncClient:
         r"""Returns information about the particular transfer
         run.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_get_transfer_run():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.GetTransferRunRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_transfer_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.GetTransferRunRequest, dict]):
                 The request object. A request to get data transfer run
@@ -999,7 +1238,7 @@ class DataTransferServiceAsyncClient:
                 Represents a data transfer run.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1056,6 +1295,22 @@ class DataTransferServiceAsyncClient:
     ) -> None:
         r"""Deletes the specified transfer run.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_delete_transfer_run():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.DeleteTransferRunRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_transfer_run(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.DeleteTransferRunRequest, dict]):
                 The request object. A request to delete data transfer
@@ -1077,7 +1332,7 @@ class DataTransferServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1131,14 +1386,34 @@ class DataTransferServiceAsyncClient:
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferRunsAsyncPager:
-        r"""Returns information about running and completed jobs.
+        r"""Returns information about running and completed
+        transfer runs.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_transfer_runs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListTransferRunsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_transfer_runs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest, dict]):
                 The request object. A request to list data transfer
-                runs. UI can use this method to show/filter specific
-                data transfer runs. The data source can use this method
-                to request all scheduled transfer runs.
+                runs.
             parent (:class:`str`):
                 Required. Name of transfer configuration for which
                 transfer runs should be retrieved. Format of transfer
@@ -1165,7 +1440,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1226,8 +1501,27 @@ class DataTransferServiceAsyncClient:
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferLogsAsyncPager:
-        r"""Returns user facing log messages for the data
-        transfer run.
+        r"""Returns log messages for the transfer run.
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_transfer_logs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListTransferLogsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_transfer_logs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsRequest, dict]):
@@ -1258,7 +1552,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1321,11 +1615,26 @@ class DataTransferServiceAsyncClient:
     ) -> datatransfer.CheckValidCredsResponse:
         r"""Returns true if valid credentials exist for the given
         data source and requesting user.
-        Some data sources doesn't support service account, so we
-        need to talk to them on behalf of the end user. This API
-        just checks whether we have OAuth token for the
-        particular user, which is a pre-requisite before user
-        can create a transfer config.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_check_valid_creds():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.CheckValidCredsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.check_valid_creds(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.CheckValidCredsRequest, dict]):
@@ -1359,7 +1668,7 @@ class DataTransferServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1405,6 +1714,72 @@ class DataTransferServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def enroll_data_sources(
+        self,
+        request: Union[datatransfer.EnrollDataSourcesRequest, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> None:
+        r"""Enroll data sources in a user project. This allows
+        users to create transfer configurations for these data
+        sources. They will also appear in the ListDataSources
+        RPC and as such, will appear in the BigQuery UI
+        'https://bigquery.cloud.google.com' (and the documents
+        can be found at
+        https://cloud.google.com/bigquery/bigquery-web-ui and
+        https://cloud.google.com/bigquery/docs/working-with-transfers).
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_enroll_data_sources():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.EnrollDataSourcesRequest(
+                )
+
+                # Make the request
+                client.enroll_data_sources(request=request)
+
+        Args:
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.EnrollDataSourcesRequest, dict]):
+                The request object. A request to enroll a set of data
+                sources so they are visible in the BigQuery UI's
+                `Transfer` tab.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        # Create or coerce a protobuf request object.
+        request = datatransfer.EnrollDataSourcesRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.enroll_data_sources,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        await rpc(
+            request, retry=retry, timeout=timeout, metadata=metadata,
+        )
+
     async def __aenter__(self):
         return self
 
