@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,24 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 import warnings
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.bigquery_datatransfer_v1.services.data_transfer_service import pagers
 from google.cloud.bigquery_datatransfer_v1.types import datatransfer
@@ -82,10 +84,8 @@ class DataTransferServiceClientMeta(type):
 
 
 class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
-    """The Google BigQuery Data Transfer Service API enables
-    BigQuery users to configure the transfer of their data from
-    other Google Products into BigQuery. This service contains
-    methods that are end user exposed. It backs up the frontend.
+    """This API allows users to manage their data transfers into
+    BigQuery.
     """
 
     @staticmethod
@@ -276,6 +276,73 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -326,50 +393,22 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, DataTransferServiceTransport):
             # transport is a DataTransferServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -381,6 +420,15 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -403,7 +451,27 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datatransfer.DataSource:
         r"""Retrieves a supported data source and returns its
-        settings, which can be used for UI rendering.
+        settings.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_get_data_source():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.GetDataSourceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_data_source(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.GetDataSourceRequest, dict]):
@@ -426,13 +494,12 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         Returns:
             google.cloud.bigquery_datatransfer_v1.types.DataSource:
-                Represents data source metadata.
-                Metadata is sufficient to render UI and
-                request proper OAuth tokens.
+                Defines the properties and custom
+                parameters for a data source.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -478,7 +545,28 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDataSourcesPager:
         r"""Lists supported data sources and returns their
-        settings, which can be used for UI rendering.
+        settings.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_data_sources():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListDataSourcesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_data_sources(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListDataSourcesRequest, dict]):
@@ -509,7 +597,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -563,6 +651,29 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
     ) -> transfer.TransferConfig:
         r"""Creates a new data transfer configuration.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_create_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                transfer_config = bigquery_datatransfer_v1.TransferConfig()
+                transfer_config.destination_dataset_id = "destination_dataset_id_value"
+
+                request = bigquery_datatransfer_v1.CreateTransferConfigRequest(
+                    parent="parent_value",
+                    transfer_config=transfer_config,
+                )
+
+                # Make the request
+                response = client.create_transfer_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.CreateTransferConfigRequest, dict]):
                 The request object. A request to create a data transfer
@@ -610,7 +721,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, transfer_config])
         if request is not None and has_flattened_params:
@@ -661,6 +772,29 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         r"""Updates a data transfer configuration.
         All fields must be set, even if they are not updated.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_update_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                transfer_config = bigquery_datatransfer_v1.TransferConfig()
+                transfer_config.destination_dataset_id = "destination_dataset_id_value"
+
+                request = bigquery_datatransfer_v1.UpdateTransferConfigRequest(
+                    transfer_config=transfer_config,
+                )
+
+                # Make the request
+                response = client.update_transfer_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.UpdateTransferConfigRequest, dict]):
                 The request object. A request to update a transfer
@@ -700,7 +834,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([transfer_config, update_mask])
         if request is not None and has_flattened_params:
@@ -749,8 +883,25 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
-        r"""Deletes a data transfer configuration,
-        including any associated transfer runs and logs.
+        r"""Deletes a data transfer configuration, including any
+        associated transfer runs and logs.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_delete_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.DeleteTransferConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_transfer_config(request=request)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.DeleteTransferConfigRequest, dict]):
@@ -773,7 +924,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -819,6 +970,25 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
     ) -> transfer.TransferConfig:
         r"""Returns information about a data transfer config.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_get_transfer_config():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.GetTransferConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_transfer_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.GetTransferConfigRequest, dict]):
                 The request object. A request to get data transfer
@@ -851,7 +1021,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -899,6 +1069,27 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         r"""Returns information about all transfer configs owned
         by a project in the specified location.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_transfer_configs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListTransferConfigsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_transfer_configs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferConfigsRequest, dict]):
                 The request object. A request to list data transfers
@@ -927,7 +1118,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -986,6 +1177,26 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         created per UTC time in the time range. DEPRECATED: use
         StartManualTransferRuns instead.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_schedule_transfer_runs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ScheduleTransferRunsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.schedule_transfer_runs(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ScheduleTransferRunsRequest, dict]):
                 The request object. A request to schedule transfer runs
@@ -1030,7 +1241,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         )
 
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, start_time, end_time])
         if request is not None and has_flattened_params:
@@ -1083,6 +1294,25 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         time range where the run_time is between start_time (inclusive)
         and end_time (exclusive), or for a specific run_time.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_start_manual_transfer_runs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.StartManualTransferRunsRequest(
+                )
+
+                # Make the request
+                response = client.start_manual_transfer_runs(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.StartManualTransferRunsRequest, dict]):
                 The request object. A request to start manual transfer
@@ -1137,6 +1367,26 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         r"""Returns information about the particular transfer
         run.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_get_transfer_run():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.GetTransferRunRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_transfer_run(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.GetTransferRunRequest, dict]):
                 The request object. A request to get data transfer run
@@ -1162,7 +1412,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
                 Represents a data transfer run.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1209,6 +1459,22 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
     ) -> None:
         r"""Deletes the specified transfer run.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_delete_transfer_run():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.DeleteTransferRunRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_transfer_run(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.DeleteTransferRunRequest, dict]):
                 The request object. A request to delete data transfer
@@ -1230,7 +1496,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1274,14 +1540,34 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferRunsPager:
-        r"""Returns information about running and completed jobs.
+        r"""Returns information about running and completed
+        transfer runs.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_transfer_runs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListTransferRunsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_transfer_runs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest, dict]):
                 The request object. A request to list data transfer
-                runs. UI can use this method to show/filter specific
-                data transfer runs. The data source can use this method
-                to request all scheduled transfer runs.
+                runs.
             parent (str):
                 Required. Name of transfer configuration for which
                 transfer runs should be retrieved. Format of transfer
@@ -1308,7 +1594,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1359,8 +1645,27 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTransferLogsPager:
-        r"""Returns user facing log messages for the data
-        transfer run.
+        r"""Returns log messages for the transfer run.
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_list_transfer_logs():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.ListTransferLogsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_transfer_logs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.ListTransferLogsRequest, dict]):
@@ -1391,7 +1696,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1444,11 +1749,26 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
     ) -> datatransfer.CheckValidCredsResponse:
         r"""Returns true if valid credentials exist for the given
         data source and requesting user.
-        Some data sources doesn't support service account, so we
-        need to talk to them on behalf of the end user. This API
-        just checks whether we have OAuth token for the
-        particular user, which is a pre-requisite before user
-        can create a transfer config.
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_check_valid_creds():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.CheckValidCredsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.check_valid_creds(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
             request (Union[google.cloud.bigquery_datatransfer_v1.types.CheckValidCredsRequest, dict]):
@@ -1482,7 +1802,7 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1518,6 +1838,73 @@ class DataTransferServiceClient(metaclass=DataTransferServiceClientMeta):
         # Done; return the response.
         return response
 
+    def enroll_data_sources(
+        self,
+        request: Union[datatransfer.EnrollDataSourcesRequest, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> None:
+        r"""Enroll data sources in a user project. This allows
+        users to create transfer configurations for these data
+        sources. They will also appear in the ListDataSources
+        RPC and as such, will appear in the BigQuery UI
+        'https://bigquery.cloud.google.com' (and the documents
+        can be found at
+        https://cloud.google.com/bigquery/bigquery-web-ui and
+        https://cloud.google.com/bigquery/docs/working-with-transfers).
+
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_datatransfer_v1
+
+            def sample_enroll_data_sources():
+                # Create a client
+                client = bigquery_datatransfer_v1.DataTransferServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_datatransfer_v1.EnrollDataSourcesRequest(
+                )
+
+                # Make the request
+                client.enroll_data_sources(request=request)
+
+        Args:
+            request (Union[google.cloud.bigquery_datatransfer_v1.types.EnrollDataSourcesRequest, dict]):
+                The request object. A request to enroll a set of data
+                sources so they are visible in the BigQuery UI's
+                `Transfer` tab.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a datatransfer.EnrollDataSourcesRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, datatransfer.EnrollDataSourcesRequest):
+            request = datatransfer.EnrollDataSourcesRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.enroll_data_sources]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        rpc(
+            request, retry=retry, timeout=timeout, metadata=metadata,
+        )
+
     def __enter__(self):
         return self
 
