@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@ from .datatransfer import (
     DataSourceParameter,
     DeleteTransferConfigRequest,
     DeleteTransferRunRequest,
+    EnrollDataSourcesRequest,
     GetDataSourceRequest,
     GetTransferConfigRequest,
     GetTransferRunRequest,
@@ -44,6 +45,7 @@ from .transfer import (
     TransferConfig,
     TransferMessage,
     TransferRun,
+    UserInfo,
     TransferState,
     TransferType,
 )
@@ -56,6 +58,7 @@ __all__ = (
     "DataSourceParameter",
     "DeleteTransferConfigRequest",
     "DeleteTransferRunRequest",
+    "EnrollDataSourcesRequest",
     "GetDataSourceRequest",
     "GetTransferConfigRequest",
     "GetTransferRunRequest",
@@ -77,6 +80,7 @@ __all__ = (
     "TransferConfig",
     "TransferMessage",
     "TransferRun",
+    "UserInfo",
     "TransferState",
     "TransferType",
 )
